@@ -4,8 +4,6 @@
 # Eventually, we should either figure out how to more cleanly integreate a custom _repr_html_
 # or make it generic enough to get a PR into xarray.
 
-from __future__ import annotations
-
 import uuid
 from collections import OrderedDict
 from collections.abc import Mapping
@@ -22,15 +20,13 @@ from xarray.core.formatting import (
     short_data_repr,
 )
 from xarray.core.options import OPTIONS, _get_boolean_with_default
+from xarray.core.datatree import DataTree
 
 STATIC_FILES = (
     ("xarray.static.html", "icons-svg-inline.html"),
     ("xopr.xarray_accessor", "style.css"),
 )
 
-if TYPE_CHECKING:
-    from xarray.core.datatree import DataTree
-
 
 @lru_cache(None)
 def _load_static_files():
